Struct RecGroup
pub struct RecGroup { /* private fields */ }Expand description
Represents a recursive type group in a WebAssembly module.
Implementations
impl RecGroup
impl RecGroup
pub fn is_explicit_rec_group(&self) -> bool
pub fn is_explicit_rec_group(&self) -> bool
Is this an explicit recursion group?
pub fn types(&self) -> impl ExactSizeIterator
pub fn types(&self) -> impl ExactSizeIterator
Returns the list of subtypes in the recursive type group.
pub fn into_types(self) -> impl ExactSizeIterator
pub fn into_types(self) -> impl ExactSizeIterator
Returns an owning iterator of all subtypes in this recursion group.
pub fn into_types_and_offsets(self) -> impl ExactSizeIterator
pub fn into_types_and_offsets(self) -> impl ExactSizeIterator
Returns an owning iterator of all subtypes in this recursion group, along with their offset.